==> alliance-5.0-20020701.tar.gz: alliance-5.0/graal/src/GME_message.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   GRAAL                           |
|                                                             |
| File    :                  Message.h                        |
|                                                             |
| Author  :                Jacomme Ludovic                    |
|                                                             |
| Date    :                  28.03.95                         |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# ifndef GRAAL_MESSAGE
# define GRAAL_MESSAGE

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  extern void GraalPromptSelectPointIdentify();
  extern void GraalPromptSelectPointCopy();
  extern void GraalPromptSelectPointMove();
  extern void GraalPromptSelectPointDelete();
  extern void GraalPromptSelectPointStretch();
  extern void GraalPromptSelectPointModify();

  extern void GraalPromptSelectWindowIdentify();
  extern void GraalPromptSelectWindowCopy();
  extern void GraalPromptSelectWindowMove();
  extern void GraalPromptSelectWindowDelete();
  extern void GraalPromptSelectWindowStretch();
  extern void GraalPromptSelectWindowModify();

  extern void GraalPromptEditCopy();
  extern void GraalPromptEditMove();
  extern void GraalPromptEditStretch();

  extern void GraalPromptModifySegment();
  extern void GraalPromptModifyConnector();
  extern void GraalPromptModifyTransistor();
  extern void GraalPromptModifyReference();
  extern void GraalPromptModifyVia();
  extern void GraalPromptModifyBigVia();

# endif

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/graal/src/GME_message.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   GRAAL                           |
|                                                             |
| File    :                  Message.h                        |
|                                                             |
| Author  :                Jacomme Ludovic                    |
|                                                             |
| Date    :                  28.03.95                         |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# ifndef GRAAL_MESSAGE
# define GRAAL_MESSAGE

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  extern void GraalPromptSelectPointIdentify();
  extern void GraalPromptSelectPointCopy();
  extern void GraalPromptSelectPointMove();
  extern void GraalPromptSelectPointDelete();
  extern void GraalPromptSelectPointStretch();
  extern void GraalPromptSelectPointModify();

  extern void GraalPromptSelectWindowIdentify();
  extern void GraalPromptSelectWindowCopy();
  extern void GraalPromptSelectWindowMove();
  extern void GraalPromptSelectWindowDelete();
  extern void GraalPromptSelectWindowStretch();
  extern void GraalPromptSelectWindowModify();

  extern void GraalPromptEditCopy();
  extern void GraalPromptEditMove();
  extern void GraalPromptEditStretch();

  extern void GraalPromptModifySegment();
  extern void GraalPromptModifyConnector();
  extern void GraalPromptModifyTransistor();
  extern void GraalPromptModifyReference();
  extern void GraalPromptModifyVia();
  extern void GraalPromptModifyBigVia();

# endif
